package cn.com.ty.lift.business.annualinspection.controller;


import cn.com.ty.lift.business.annualinspection.dto.InspectionCondition;
import cn.com.ty.lift.business.annualinspection.entity.AnnualInspection;
import cn.com.ty.lift.business.annualinspection.service.impl.AnnualInspectionServiceImpl;
import cn.com.ty.lift.business.common.RestResult;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 年检记录 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2019-12-10
 */
@AllArgsConstructor
@RestController
@RequestMapping("/annualinspection/annual-inspection")
public class AnnualInspectionController {

    private AnnualInspectionServiceImpl annualInspectionService;

    /**
     * @description 根据id查询
     * @date 2019/12/10 10:19
     * @param
     * @return
     */
    @PostMapping("findOne")
    public RestResponse findOne(Long id){
        if(null == id || id <= 0){
            return RestResult.errParam();
        }
        AnnualInspection entity = annualInspectionService.getById(id);
        if(null == entity){
            return RestResult.fail();
        }
        return RestResult.okData(entity);
    }

    /**
     * @description 根据条件查询年检记录
     * @date 2019/12/11 17:15
     * @param
     * @return
     */
    @PostMapping("page")
    public RestResponse page(@RequestBody InspectionCondition condition){
        if(null == condition){
            return RestResult.errParam();
        }
        String info = condition.getInfo();
        if(StrUtil.isNotBlank(info)){
            condition.setInfo(StrUtil.format("%{}%",info));
        }

        IPage<AnnualInspection> page = annualInspectionService.listByCondition(condition);
        if(null == page){
            return RestResult.fail();
        }
        return RestResult.okData(page);
    }

    /**
     * @description 修改年检信息
     * @date 2019/12/10 10:04
     * @param
     * @return
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody AnnualInspection entity){
        if(null == entity){
            return RestResult.errParam();
        }
        boolean result = annualInspectionService.saveOrUpdate(entity);
        if(result){
            return RestResult.okData(result);
        }
        return RestResult.fail();
    }
}
